@@ -1,6 +1,6 @@
 import json
 import subprocess
-from .User import User
+from axis42.User import User
 
 class Axis_api:
     """Axis api will handle all the requests to the Axis server.
